TOTP class
Constructors
- TOTP()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decryptData(
String encryptedText, String password) → Future< String> -
encryptData(
String text, String password) → Future< String> -
generateTOTP(
String secret, {int timeStep = 30, int digits = 6}) → String